@@ -2,13 +2,9 @@ var classcl_1_1_kernel =
 [
     [ "Kernel", "classcl_1_1_kernel.html#a69b2fc97f80d90a23927a74395d09ec9", null ],
     [ "Kernel", "classcl_1_1_kernel.html#a0c71f37cb53fbe492847fbb2dff2bfed", null ],
-    [ "Kernel", "classcl_1_1_kernel.html#a93b516f37993297101dd9d30a4572b23", null ],
-    [ "Kernel", "classcl_1_1_kernel.html#a0869347f24520f2d59222f74297c5fe5", null ],
     [ "clone", "classcl_1_1_kernel.html#aec57511d2e4ef1080c27918f79bcb917", null ],
     [ "enableFineGrainedSystemSVM", "classcl_1_1_kernel.html#aed996666686cddb41d660839e709fcd0", null ],
     [ "operator=", "classcl_1_1_kernel.html#ab9fbaa8ff250cc478a84387c017493f0", null ],
-    [ "operator=", "classcl_1_1_kernel.html#a52ba1d47a5dae7b90d57760cac3507d0", null ],
-    [ "operator=", "classcl_1_1_kernel.html#a9388f0ab102312588a38457c41c68ac0", null ],
     [ "setArg", "classcl_1_1_kernel.html#a3ec081fb9656b0780d808563256dfeff", null ],
     [ "setArg", "classcl_1_1_kernel.html#a9516e70e10909526dfb01f6cfe8b61bd", null ],
     [ "setArg", "classcl_1_1_kernel.html#a7d5ad9296c70602f6c04b841115afec6", null ],
