@@ -1,5 +1,19 @@
 var NAVTREEINDEX2 =
 {
+"hierarchy.html":[5,2],
+"index.html":[],
+"index.html#compatibility":[1],
+"index.html#example":[3],
+"index.html#intro":[0],
+"index.html#parameterization":[2],
+"namespacecl.html":[4,0,0],
+"namespacecl.html#a02c4368c6ce7a1a99132eafd5dc96fa9":[4,0,0,43],
+"namespacecl.html#a05791e9d5da23b21abd6e319fb262c9f":[4,0,0,42],
+"namespacecl.html#a1197a833cdd6664f206b079f2bebd2eb":[4,0,0,45],
+"namespacecl.html#a2903d8ce897eef7efca4ab6f32f2a197":[4,0,0,39],
+"namespacecl.html#a2f71ed9a316daf59c03c0f3ba62f1bd3":[4,0,0,44],
+"namespacecl.html#a2f9d06d8196d7a2f4cf196d5bb7e5dd0":[4,0,0,52],
+"namespacecl.html#a2fc824c118740089633cc15e7107f3f0":[4,0,0,54],
 "namespacecl.html#a43fd451f30944f957126b167b4eb0664":[4,0,0,40],
 "namespacecl.html#a445d7d2f4c3234dc5fbd2d254eb39e22":[4,0,0,38],
 "namespacecl.html#a640c02cb285c5ab57ab8669bc2146643":[4,0,0,46],
@@ -38,23 +52,23 @@ var NAVTREEINDEX2 =
 "pages.html":[],
 "structcl_1_1_image_format.html":[4,0,0,18],
 "structcl_1_1_image_format.html":[5,0,0,20],
-"structcl_1_1_image_format.html#a039deeaa451a52448014794e7dae30ba":[5,0,0,20,1],
 "structcl_1_1_image_format.html#a039deeaa451a52448014794e7dae30ba":[4,0,0,18,1],
-"structcl_1_1_image_format.html#a74296cd49ed08b0521e8b6b26e51608f":[5,0,0,20,3],
+"structcl_1_1_image_format.html#a039deeaa451a52448014794e7dae30ba":[5,0,0,20,1],
 "structcl_1_1_image_format.html#a74296cd49ed08b0521e8b6b26e51608f":[4,0,0,18,3],
-"structcl_1_1_image_format.html#a935a0799f110ada43afb5ccfacf6197b":[5,0,0,20,2],
+"structcl_1_1_image_format.html#a74296cd49ed08b0521e8b6b26e51608f":[5,0,0,20,3],
 "structcl_1_1_image_format.html#a935a0799f110ada43afb5ccfacf6197b":[4,0,0,18,2],
-"structcl_1_1_image_format.html#adf48b6e9dfdfefb7583e20826c3b4a14":[5,0,0,20,0],
+"structcl_1_1_image_format.html#a935a0799f110ada43afb5ccfacf6197b":[5,0,0,20,2],
 "structcl_1_1_image_format.html#adf48b6e9dfdfefb7583e20826c3b4a14":[4,0,0,18,0],
+"structcl_1_1_image_format.html#adf48b6e9dfdfefb7583e20826c3b4a14":[5,0,0,20,0],
 "structcl_1_1_local_space_arg.html":[4,0,0,22],
 "structcl_1_1_local_space_arg.html":[5,0,0,24],
-"structcl_1_1_s_v_m_allocator_1_1rebind.html":[5,0,0,31,0],
 "structcl_1_1_s_v_m_allocator_1_1rebind.html":[4,0,0,29,0],
-"structcl_1_1_s_v_m_allocator_3_01void_00_01_s_v_m_trait_01_4_1_1rebind.html":[5,0,0,32,0],
+"structcl_1_1_s_v_m_allocator_1_1rebind.html":[5,0,0,31,0],
 "structcl_1_1_s_v_m_allocator_3_01void_00_01_s_v_m_trait_01_4_1_1rebind.html":[4,0,0,30,0],
+"structcl_1_1_s_v_m_allocator_3_01void_00_01_s_v_m_trait_01_4_1_1rebind.html":[5,0,0,32,0],
 "structcl_1_1compatibility_1_1make__kernel.html":[5,0,0,0,0],
-"structcl_1_1compatibility_1_1make__kernel.html#aaa094f5455d73fae53eb99b374f05eec":[5,0,0,0,0,1],
-"structcl_1_1compatibility_1_1make__kernel.html#ab5a793302f7651ad151a1e4b585be5d4":[5,0,0,0,0,0],
+"structcl_1_1compatibility_1_1make__kernel.html#a9077088cfa3f9abe614fda3cf6e59d36":[5,0,0,0,0,1],
+"structcl_1_1compatibility_1_1make__kernel.html#ab124d932c72bfc60c3b6f13b1ba7b4cb":[5,0,0,0,0,0],
 "structcl_1_1detail_1_1_get_info_functor0.html":[5,0,0,1,1],
 "structcl_1_1detail_1_1_get_info_functor1.html":[5,0,0,1,2],
 "structcl_1_1detail_1_1_kernel_argument_handler.html":[5,0,0,1,3],
