@@ -6,7 +6,7 @@ var indexSectionsWithContent =
   3: "o",
   4: "abcdegiklmnoprsuw",
   5: "acfrt",
-  6: "o"
+  6: "bco"
 };
 
 var indexSectionNames =
